@@ -148,7 +148,7 @@ static GdkPixbuf *xfce_panel_image_scale_pixbuf         (GdkPixbuf       *source
 
 
 
-G_DEFINE_TYPE (XfcePanelImage, xfce_panel_image, GTK_TYPE_WIDGET)
+G_DEFINE_TYPE_WITH_PRIVATE (XfcePanelImage, xfce_panel_image, GTK_TYPE_WIDGET)
 
 
 
@@ -158,8 +158,6 @@ xfce_panel_image_class_init (XfcePanelImageClass *klass)
   GObjectClass   *gobject_class;
   GtkWidgetClass *gtkwidget_class;
 
-  g_type_class_add_private (klass, sizeof (XfcePanelImagePrivate));
-
   gobject_class = G_OBJECT_CLASS (klass);
   gobject_class->set_property = xfce_panel_image_set_property;
   gobject_class->get_property = xfce_panel_image_get_property;
@@ -224,7 +222,7 @@ xfce_panel_image_init (XfcePanelImage *image)
 {
   gtk_widget_set_has_window (GTK_WIDGET (image), FALSE);
 
-  image->priv = G_TYPE_INSTANCE_GET_PRIVATE (image, XFCE_TYPE_PANEL_IMAGE, XfcePanelImagePrivate);
+  image->priv = xfce_panel_image_get_instance_private (image);
 
   image->priv->pixbuf = NULL;
   image->priv->cache = NULL;
@@ -308,7 +306,6 @@ xfce_panel_image_finalize (GObject *object)
 
 
 
-//#if GTK_CHECK_VERSION (3, 0, 0) && !GTK_CHECK_VERSION (3, 10, 0)
 #if GTK_CHECK_VERSION (3, 0, 0)
 #define GTK_BUTTON_SIZING_FIX
 #endif
@@ -704,7 +701,7 @@ xfce_panel_image_load (gpointer data)
   if (priv->pixbuf != NULL)
     {
       /* use the pixbuf set by the user */
-      pixbuf = g_object_ref (G_OBJECT (priv->pixbuf));
+      pixbuf = (GdkPixbuf *) g_object_ref (G_OBJECT (priv->pixbuf));
 
       if (G_LIKELY (pixbuf != NULL))
         {
@@ -758,7 +755,7 @@ xfce_panel_image_scale_pixbuf (GdkPixbuf *source,
 
   /* check if we need to scale */
   if (source_width <= dest_width && source_height <= dest_height)
-    return g_object_ref (G_OBJECT (source));
+    return (GdkPixbuf *) g_object_ref (G_OBJECT (source));
 
   /* calculate the new dimensions */
 
