@@ -730,6 +730,9 @@ xfce_panel_plugin_init (XfcePanelPlugin *plugin)
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 #endif
 
+  if (g_getenv ("PANEL_GDK_CORE_DEVICE_EVENTS"))
+    g_unsetenv ("GDK_CORE_DEVICE_EVENTS");
+
   /* hide the event box window to make the plugin transparent */
   gtk_event_box_set_visible_window (GTK_EVENT_BOX (plugin), FALSE);
 }
@@ -1081,8 +1084,8 @@ xfce_panel_plugin_menu_remove (XfcePanelPlugin *plugin)
       gtk_widget_get_screen (GTK_WIDGET (plugin)));
   gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
       _("If you remove the item from the panel, it is permanently lost."));
-  gtk_dialog_add_buttons (GTK_DIALOG (dialog), _("Cancel"),
-      GTK_RESPONSE_NO, _("Remove"), GTK_RESPONSE_YES, NULL);
+  gtk_dialog_add_buttons (GTK_DIALOG (dialog), _("_Cancel"),
+      GTK_RESPONSE_NO, _("_Remove"), GTK_RESPONSE_YES, NULL);
   gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_NO);
 
   if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_YES)
@@ -1370,7 +1373,7 @@ G_GNUC_END_IGNORE_DEPRECATIONS
       gtk_menu_shell_append (GTK_MENU_SHELL (submenu), item);
       gtk_widget_show (item);
 
-      image = gtk_image_new_from_icon_name ("gtk-help", GTK_ICON_SIZE_MENU);
+      image = gtk_image_new_from_icon_name ("help-browser", GTK_ICON_SIZE_MENU);
 G_GNUC_BEGIN_IGNORE_DEPRECATIONS
       gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), image);
 G_GNUC_END_IGNORE_DEPRECATIONS
