@@ -25,7 +25,9 @@ G_BEGIN_DECLS
 
 #define XFCE_46_CONFIG  "xfce4" G_DIR_SEPARATOR_S "panel" G_DIR_SEPARATOR_S "panels.xml"
 
-gboolean migrate_46 (const gchar *filename, GError **error);
+gboolean migrate_46 (const gchar    *filename,
+                     XfconfChannel  *channel,
+                     GError        **error);
 
 G_END_DECLS
 
