@@ -75,6 +75,10 @@ wrapper_gproxy_set (XfcePanelPluginProvider *provider,
           xfce_panel_plugin_provider_set_size (provider, g_variant_get_int32 (variant));
           break;
 
+        case PROVIDER_PROP_TYPE_SET_ICON_SIZE:
+          xfce_panel_plugin_provider_set_icon_size (provider, g_variant_get_int32 (variant));
+          break;
+
         case PROVIDER_PROP_TYPE_SET_MODE:
           xfce_panel_plugin_provider_set_mode (provider, g_variant_get_int32 (variant));
           break;
@@ -125,6 +129,7 @@ wrapper_gproxy_set (XfcePanelPluginProvider *provider,
 
         case PROVIDER_PROP_TYPE_ACTION_QUIT_FOR_RESTART:
           retval = PLUGIN_EXIT_SUCCESS_AND_RESTART;
+          /* fall through */
         case PROVIDER_PROP_TYPE_ACTION_QUIT:
           gtk_main_quit ();
           break;
